@@ -140,11 +140,11 @@ class Path:
 		:rtype: Path
 		"""
 		if absolute:
-			return self.__class__(string=get_parent_directory(self.absolute_path))
+			return Path(string=get_parent_directory(self.absolute_path))
 		else:
 			string_except_name_and_extension = self._string[:-len(self.name_and_extension)]
 			if len(string_except_name_and_extension) > 0:
-				return self.__class__(string=string_except_name_and_extension)
+				return Path(string=string_except_name_and_extension)
 			else:
 				return self.get_current_directory(show_size=self._show_size)
 
@@ -397,6 +397,15 @@ class Path:
 			path = item
 		return path in list_directory(path=self.path)
 
+	def get_num_files(self):
+		if self.is_directory():
+			return len([x for x in list_directory(path=self.path)])
+		else:
+			raise NotADirectoryError(f'{self.path} is not a directory!')
+
+	def is_empty(self):
+		return self.get_num_files() == 0
+
 	def list(self, show_size=None):
 		"""
 		:rtype: list[Path]
@@ -519,7 +528,7 @@ class Path:
 		if delete_original:
 			self.delete()
 
-		return self.__class__(string=result)
+		return Path(string=result)
 
 	def unzip(self, unzip_path=None, delete_original=False):
 		"""
@@ -548,7 +557,7 @@ class Path:
 		if delete_original:
 			self.delete()
 
-		return self.__class__(string=unzip_path)
+		return Path(string=unzip_path)
 
 	def is_zipfile(self):
 		"""
